==> evolution-3.26.6.tar.xz: evolution-3.26.6/src/e-util/e-util.h <==
/*
 * e-util.h
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, see <http://www.gnu.org/licenses/>.
 *
 */

#ifndef E_UTIL_H
#define E_UTIL_H

#define __E_UTIL_H_INSIDE__

#include <libedataserver/libedataserver.h>

#include <e-util/e-accounts-window.h>
#include <e-util/e-action-combo-box.h>
#include <e-util/e-activity-bar.h>
#include <e-util/e-activity-proxy.h>
#include <e-util/e-activity.h>
#include <e-util/e-alarm-selector.h>
#include <e-util/e-alert-bar.h>
#include <e-util/e-alert-dialog.h>
#include <e-util/e-alert-sink.h>
#include <e-util/e-alert.h>
#include <e-util/e-attachment-bar.h>
#include <e-util/e-attachment-dialog.h>
#include <e-util/e-attachment-handler-image.h>
#include <e-util/e-attachment-handler.h>
#include <e-util/e-attachment-icon-view.h>
#include <e-util/e-attachment-paned.h>
#include <e-util/e-attachment-store.h>
#include <e-util/e-attachment-tree-view.h>
#include <e-util/e-attachment-view.h>
#include <e-util/e-attachment.h>
#include <e-util/e-auth-combo-box.h>
#include <e-util/e-autocomplete-selector.h>
#include <e-util/e-bit-array.h>
#include <e-util/e-book-source-config.h>
#include <e-util/e-buffer-tagger.h>
#include <e-util/e-cal-source-config.h>
#include <e-util/e-calendar-item.h>
#include <e-util/e-calendar.h>
#include <e-util/e-canvas-background.h>
#include <e-util/e-canvas-utils.h>
#include <e-util/e-canvas-vbox.h>
#include <e-util/e-canvas.h>
#include <e-util/e-categories-config.h>
#include <e-util/e-categories-dialog.h>
#include <e-util/e-categories-editor.h>
#include <e-util/e-categories-selector.h>
#include <e-util/e-category-completion.h>
#include <e-util/e-category-editor.h>
#include <e-util/e-cell-checkbox.h>
#include <e-util/e-cell-combo.h>
#include <e-util/e-cell-date-edit.h>
#include <e-util/e-cell-date-int.h>
#include <e-util/e-cell-date.h>
#include <e-util/e-cell-hbox.h>
#include <e-util/e-cell-number.h>
#include <e-util/e-cell-percent.h>
#include <e-util/e-cell-pixbuf.h>
#include <e-util/e-cell-popup.h>
#include <e-util/e-cell-size.h>
#include <e-util/e-cell-text.h>
#include <e-util/e-cell-toggle.h>
#include <e-util/e-cell-tree.h>
#include <e-util/e-cell-vbox.h>
#include <e-util/e-cell.h>
#include <e-util/e-charset-combo-box.h>
#include <e-util/e-charset.h>
#include <e-util/e-client-cache.h>
#include <e-util/e-client-combo-box.h>
#include <e-util/e-client-selector.h>
#include <e-util/e-color-chooser-widget.h>
#include <e-util/e-color-combo.h>
#include <e-util/e-config.h>
#include <e-util/e-config-lookup.h>
#include <e-util/e-config-lookup-result.h>
#include <e-util/e-config-lookup-result-simple.h>
#include <e-util/e-conflict-search-selector.h>
#include <e-util/e-contact-store.h>
#include <e-util/e-content-editor.h>
#include <e-util/e-content-request.h>
#include <e-util/e-data-capture.h>
#include <e-util/e-dateedit.h>
#include <e-util/e-datetime-format.h>
#include <e-util/e-destination-store.h>
#include <e-util/e-dialog-utils.h>
#include <e-util/e-dialog-widgets.h>
#include <e-util/e-emoticon-action.h>
#include <e-util/e-emoticon-chooser-menu.h>
#include <e-util/e-emoticon-chooser.h>
#include <e-util/e-emoticon-tool-button.h>
#include <e-util/e-emoticon.h>
#include <e-util/e-event.h>
#include <e-util/e-file-request.h>
#include <e-util/e-file-utils.h>
#include <e-util/e-filter-code.h>
#include <e-util/e-filter-color.h>
#include <e-util/e-filter-datespec.h>
#include <e-util/e-filter-element.h>
#include <e-util/e-filter-file.h>
#include <e-util/e-filter-input.h>
#include <e-util/e-filter-int.h>
#include <e-util/e-filter-option.h>
#include <e-util/e-filter-part.h>
#include <e-util/e-filter-rule.h>
#include <e-util/e-focus-tracker.h>
#ifndef E_UTIL_INCLUDE_WITHOUT_WEBKIT
#include <e-util/e-html-editor-actions.h>
#include <e-util/e-html-editor-cell-dialog.h>
#include <e-util/e-html-editor-dialog.h>
#include <e-util/e-html-editor-find-dialog.h>
#include <e-util/e-html-editor-hrule-dialog.h>
#include <e-util/e-html-editor-image-dialog.h>
#include <e-util/e-html-editor-link-dialog.h>
#include <e-util/e-html-editor-page-dialog.h>
#include <e-util/e-html-editor-paragraph-dialog.h>
#include <e-util/e-html-editor-replace-dialog.h>
#include <e-util/e-html-editor-spell-check-dialog.h>
#include <e-util/e-html-editor-table-dialog.h>
#include <e-util/e-html-editor-text-dialog.h>
#include <e-util/e-html-editor.h>
#endif
#include <e-util/e-html-utils.h>
#include <e-util/e-icon-factory.h>
#include <e-util/e-image-chooser.h>
#include <e-util/e-image-chooser-dialog.h>
#include <e-util/e-import-assistant.h>
#include <e-util/e-import.h>
#include <e-util/e-interval-chooser.h>
#include <e-util/e-mail-identity-combo-box.h>
#include <e-util/e-mail-signature-combo-box.h>
#ifndef E_UTIL_INCLUDE_WITHOUT_WEBKIT
#include <e-util/e-mail-signature-editor.h>
#include <e-util/e-mail-signature-manager.h>
#include <e-util/e-mail-signature-preview.h>
#endif
#include <e-util/e-mail-signature-script-dialog.h>
#include <e-util/e-mail-signature-tree-view.h>
#include <e-util/e-map.h>
#include <e-util/e-menu-tool-action.h>
#include <e-util/e-menu-tool-button.h>
#include <e-util/e-misc-utils.h>
#include <e-util/e-mktemp.h>
#include <e-util/e-name-selector-dialog.h>
#include <e-util/e-name-selector-entry.h>
#include <e-util/e-name-selector-list.h>
#include <e-util/e-name-selector-model.h>
#include <e-util/e-name-selector.h>
#include <e-util/e-online-button.h>
#include <e-util/e-paned.h>
#include <e-util/e-passwords.h>
#include <e-util/e-photo-cache.h>
#include <e-util/e-photo-source.h>
#include <e-util/e-picture-gallery.h>
#include <e-util/e-plugin-ui.h>
#include <e-util/e-plugin.h>
#include <e-util/e-poolv.h>
#include <e-util/e-popup-action.h>
#include <e-util/e-popup-menu.h>
#include <e-util/e-port-entry.h>
#include <e-util/e-preferences-window.h>
#ifndef E_UTIL_INCLUDE_WITHOUT_WEBKIT
#include <e-util/e-preview-pane.h>
#endif
#include <e-util/e-print.h>
#include <e-util/e-printable.h>
#include <e-util/e-proxy-combo-box.h>
#include <e-util/e-proxy-editor.h>
#include <e-util/e-proxy-link-selector.h>
#include <e-util/e-proxy-preferences.h>
#include <e-util/e-proxy-selector.h>
#include <e-util/e-reflow-model.h>
#include <e-util/e-reflow.h>
#include <e-util/e-rule-context.h>
#include <e-util/e-rule-editor.h>
#ifndef E_UTIL_INCLUDE_WITHOUT_WEBKIT
#include <e-util/e-search-bar.h>
#endif
#include <e-util/e-selectable.h>
#include <e-util/e-selection-model-array.h>
#include <e-util/e-selection-model-simple.h>
#include <e-util/e-selection-model.h>
#include <e-util/e-selection.h>
#include <e-util/e-send-options.h>
#include <e-util/e-simple-async-result.h>
#include <e-util/e-sorter-array.h>
#include <e-util/e-sorter.h>
#include <e-util/e-source-combo-box.h>
#include <e-util/e-source-config-backend.h>
#include <e-util/e-source-config-dialog.h>
#include <e-util/e-source-config.h>
#include <e-util/e-source-conflict-search.h>
#include <e-util/e-source-selector-dialog.h>
#include <e-util/e-source-selector.h>
#include <e-util/e-source-util.h>
#include <e-util/e-spell-checker.h>
#include <e-util/e-spell-dictionary.h>
#include <e-util/e-spell-entry.h>
#include <e-util/e-spell-text-view.h>
#include <e-util/e-spinner.h>
#include <e-util/e-stock-request.h>
#include <e-util/e-table-click-to-add.h>
#include <e-util/e-table-col-dnd.h>
#include <e-util/e-table-col.h>
#include <e-util/e-table-column-selector.h>
#include <e-util/e-table-column-specification.h>
#include <e-util/e-table-config.h>
#include <e-util/e-table-defines.h>
#include <e-util/e-table-extras.h>
#include <e-util/e-table-field-chooser-dialog.h>
#include <e-util/e-table-field-chooser-item.h>
#include <e-util/e-table-field-chooser.h>
#include <e-util/e-table-group-container.h>
#include <e-util/e-table-group-leaf.h>
#include <e-util/e-table-group.h>
#include <e-util/e-table-header-item.h>
#include <e-util/e-table-header-utils.h>
#include <e-util/e-table-header.h>
#include <e-util/e-table-item.h>
#include <e-util/e-table-model.h>
#include <e-util/e-table-one.h>
#include <e-util/e-table-search.h>
#include <e-util/e-table-selection-model.h>
#include <e-util/e-table-sort-info.h>
#include <e-util/e-table-sorted-variable.h>
#include <e-util/e-table-sorted.h>
#include <e-util/e-table-sorter.h>
#include <e-util/e-table-sorting-utils.h>
#include <e-util/e-table-specification.h>
#include <e-util/e-table-state.h>
#include <e-util/e-table-subset-variable.h>
#include <e-util/e-table-subset.h>
#include <e-util/e-table-utils.h>
#include <e-util/e-table.h>
#include <e-util/e-text-event-processor-emacs-like.h>
#include <e-util/e-text-event-processor-types.h>
#include <e-util/e-text-event-processor.h>
#include <e-util/e-text-model-repos.h>
#include <e-util/e-text-model.h>
#include <e-util/e-text.h>
#include <e-util/e-timezone-dialog.h>
#include <e-util/e-tree-model-generator.h>
#include <e-util/e-tree-model.h>
#include <e-util/e-tree-selection-model.h>
#include <e-util/e-tree-table-adapter.h>
#include <e-util/e-tree-view-frame.h>
#include <e-util/e-tree.h>
#include <e-util/e-unicode.h>
#include <e-util/e-url-entry.h>
#include <e-util/e-util-enums.h>
#include <e-util/e-util-enumtypes.h>
#include <e-util/e-webdav-browser.h>
#ifndef E_UTIL_INCLUDE_WITHOUT_WEBKIT
#include <e-util/e-web-view-preview.h>
#include <e-util/e-web-view.h>
#endif
#include <e-util/e-widget-undo.h>
#include <e-util/e-xml-utils.h>
#include <e-util/ea-cell-table.h>
#include <e-util/ea-factory.h>
#include <e-util/gal-view-collection.h>
#include <e-util/gal-view-etable.h>
#include <e-util/gal-view-instance-save-as-dialog.h>
#include <e-util/gal-view-instance.h>
#include <e-util/gal-view.h>

#undef __E_UTIL_H_INSIDE__

#endif /* E_UTIL_H */

==> evolution-3.45.1.tar.xz: evolution-3.45.1/src/e-util/e-util.h <==
/*
 * e-util.h
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, see <http://www.gnu.org/licenses/>.
 *
 */

#ifndef E_UTIL_H
#define E_UTIL_H

#define __E_UTIL_H_INSIDE__

#include <libedataserver/libedataserver.h>

#include <e-util/e-accounts-window.h>
#include <e-util/e-action-combo-box.h>
#include <e-util/e-activity-bar.h>
#include <e-util/e-activity-proxy.h>
#include <e-util/e-activity.h>
#include <e-util/e-alarm-selector.h>
#include <e-util/e-alert-bar.h>
#include <e-util/e-alert-dialog.h>
#include <e-util/e-alert-sink.h>
#include <e-util/e-alert.h>
#include <e-util/e-attachment-bar.h>
#include <e-util/e-attachment-dialog.h>
#include <e-util/e-attachment-handler-image.h>
#include <e-util/e-attachment-handler.h>
#include <e-util/e-attachment-icon-view.h>
#include <e-util/e-attachment-paned.h>
#include <e-util/e-attachment-store.h>
#include <e-util/e-attachment-tree-view.h>
#include <e-util/e-attachment-view.h>
#include <e-util/e-attachment.h>
#include <e-util/e-auth-combo-box.h>
#include <e-util/e-autocomplete-selector.h>
#include <e-util/e-bit-array.h>
#include <e-util/e-book-source-config.h>
#include <e-util/e-cal-source-config.h>
#include <e-util/e-calendar-item.h>
#include <e-util/e-calendar.h>
#include <e-util/e-canvas-background.h>
#include <e-util/e-canvas-utils.h>
#include <e-util/e-canvas-vbox.h>
#include <e-util/e-canvas.h>
#include <e-util/e-categories-config.h>
#include <e-util/e-categories-dialog.h>
#include <e-util/e-categories-editor.h>
#include <e-util/e-categories-selector.h>
#include <e-util/e-category-completion.h>
#include <e-util/e-category-editor.h>
#include <e-util/e-cell-checkbox.h>
#include <e-util/e-cell-combo.h>
#include <e-util/e-cell-date-edit.h>
#include <e-util/e-cell-date-int.h>
#include <e-util/e-cell-date.h>
#include <e-util/e-cell-hbox.h>
#include <e-util/e-cell-number.h>
#include <e-util/e-cell-percent.h>
#include <e-util/e-cell-pixbuf.h>
#include <e-util/e-cell-popup.h>
#include <e-util/e-cell-size.h>
#include <e-util/e-cell-text.h>
#include <e-util/e-cell-toggle.h>
#include <e-util/e-cell-tree.h>
#include <e-util/e-cell-vbox.h>
#include <e-util/e-cell.h>
#include <e-util/e-charset-combo-box.h>
#include <e-util/e-charset.h>
#include <e-util/e-client-cache.h>
#include <e-util/e-client-combo-box.h>
#include <e-util/e-client-selector.h>
#include <e-util/e-collection-account-wizard.h>
#include <e-util/e-color-chooser-widget.h>
#include <e-util/e-color-combo.h>
#include <e-util/e-color-scheme-watcher.h>
#include <e-util/e-config.h>
#include <e-util/e-config-lookup.h>
#include <e-util/e-config-lookup-result.h>
#include <e-util/e-config-lookup-result-simple.h>
#include <e-util/e-config-lookup-worker.h>
#include <e-util/e-conflict-search-selector.h>
#include <e-util/e-contact-store.h>
#include <e-util/e-content-editor.h>
#include <e-util/e-content-request.h>
#include <e-util/e-data-capture.h>
#include <e-util/e-dateedit.h>
#include <e-util/e-datetime-format.h>
#include <e-util/e-destination-store.h>
#include <e-util/e-dialog-utils.h>
#include <e-util/e-dialog-widgets.h>
#include <e-util/e-ellipsized-combo-box-text.h>
#include <e-util/e-emoticon-action.h>
#include <e-util/e-emoticon-chooser-menu.h>
#include <e-util/e-emoticon-chooser.h>
#include <e-util/e-emoticon-tool-button.h>
#include <e-util/e-emoticon.h>
#include <e-util/e-event.h>
#include <e-util/e-file-request.h>
#include <e-util/e-file-utils.h>
#include <e-util/e-filter-code.h>
#include <e-util/e-filter-color.h>
#include <e-util/e-filter-datespec.h>
#include <e-util/e-filter-element.h>
#include <e-util/e-filter-file.h>
#include <e-util/e-filter-input.h>
#include <e-util/e-filter-int.h>
#include <e-util/e-filter-label.h>
#include <e-util/e-filter-option.h>
#include <e-util/e-filter-part.h>
#include <e-util/e-filter-rule.h>
#include <e-util/e-focus-tracker.h>
#ifndef E_UTIL_INCLUDE_WITHOUT_WEBKIT
#include <e-util/e-html-editor-actions.h>
#include <e-util/e-html-editor-cell-dialog.h>
#include <e-util/e-html-editor-dialog.h>
#include <e-util/e-html-editor-find-dialog.h>
#include <e-util/e-html-editor-hrule-dialog.h>
#include <e-util/e-html-editor-image-dialog.h>
#include <e-util/e-html-editor-link-dialog.h>
#include <e-util/e-html-editor-page-dialog.h>
#include <e-util/e-html-editor-paragraph-dialog.h>
#include <e-util/e-html-editor-replace-dialog.h>
#include <e-util/e-html-editor-spell-check-dialog.h>
#include <e-util/e-html-editor-table-dialog.h>
#include <e-util/e-html-editor-text-dialog.h>
#include <e-util/e-html-editor.h>
#endif
#include <e-util/e-html-utils.h>
#include <e-util/e-icon-factory.h>
#include <e-util/e-image-chooser.h>
#include <e-util/e-image-chooser-dialog.h>
#include <e-util/e-import-assistant.h>
#include <e-util/e-import.h>
#include <e-util/e-interval-chooser.h>
#include <e-util/e-mail-identity-combo-box.h>
#include <e-util/e-mail-signature-combo-box.h>
#ifndef E_UTIL_INCLUDE_WITHOUT_WEBKIT
#include <e-util/e-mail-signature-editor.h>
#include <e-util/e-mail-signature-manager.h>
#include <e-util/e-mail-signature-preview.h>
#endif
#include <e-util/e-mail-signature-script-dialog.h>
#include <e-util/e-mail-signature-tree-view.h>
#include <e-util/e-map.h>
#include <e-util/e-markdown-editor.h>
#include <e-util/e-markdown-utils.h>
#include <e-util/e-menu-tool-action.h>
#include <e-util/e-menu-tool-button.h>
#include <e-util/e-misc-utils.h>
#include <e-util/e-mktemp.h>
#include <e-util/e-month-widget.h>
#include <e-util/e-name-selector-dialog.h>
#include <e-util/e-name-selector-entry.h>
#include <e-util/e-name-selector-list.h>
#include <e-util/e-name-selector-model.h>
#include <e-util/e-name-selector.h>
#include <e-util/e-online-button.h>
#include <e-util/e-paned.h>
#include <e-util/e-passwords.h>
#include <e-util/e-photo-cache.h>
#include <e-util/e-photo-source.h>
#include <e-util/e-picture-gallery.h>
#include <e-util/e-plugin-ui.h>
#include <e-util/e-plugin.h>
#include <e-util/e-poolv.h>
#include <e-util/e-popup-action.h>
#include <e-util/e-popup-menu.h>
#include <e-util/e-port-entry.h>
#include <e-util/e-preferences-window.h>
#ifndef E_UTIL_INCLUDE_WITHOUT_WEBKIT
#include <e-util/e-preview-pane.h>
#endif
#include <e-util/e-print.h>
#include <e-util/e-printable.h>
#include <e-util/e-proxy-combo-box.h>
#include <e-util/e-proxy-editor.h>
#include <e-util/e-proxy-link-selector.h>
#include <e-util/e-proxy-preferences.h>
#include <e-util/e-proxy-selector.h>
#include <e-util/e-reflow-model.h>
#include <e-util/e-reflow.h>
#include <e-util/e-rule-context.h>
#include <e-util/e-rule-editor.h>
#ifndef E_UTIL_INCLUDE_WITHOUT_WEBKIT
#include <e-util/e-search-bar.h>
#endif
#include <e-util/e-selectable.h>
#include <e-util/e-selection-model-array.h>
#include <e-util/e-selection-model-simple.h>
#include <e-util/e-selection-model.h>
#include <e-util/e-selection.h>
#include <e-util/e-send-options.h>
#include <e-util/e-simple-async-result.h>
#include <e-util/e-sorter-array.h>
#include <e-util/e-sorter.h>
#include <e-util/e-source-combo-box.h>
#include <e-util/e-source-config-backend.h>
#include <e-util/e-source-config-dialog.h>
#include <e-util/e-source-config.h>
#include <e-util/e-source-conflict-search.h>
#include <e-util/e-source-selector-dialog.h>
#include <e-util/e-source-selector.h>
#include <e-util/e-source-util.h>
#include <e-util/e-spell-checker.h>
#include <e-util/e-spell-dictionary.h>
#include <e-util/e-spell-entry.h>
#include <e-util/e-spell-text-view.h>
#include <e-util/e-spinner.h>
#include <e-util/e-stock-request.h>
#include <e-util/e-table-click-to-add.h>
#include <e-util/e-table-col-dnd.h>
#include <e-util/e-table-col.h>
#include <e-util/e-table-column-selector.h>
#include <e-util/e-table-column-specification.h>
#include <e-util/e-table-config.h>
#include <e-util/e-table-defines.h>
#include <e-util/e-table-extras.h>
#include <e-util/e-table-field-chooser-dialog.h>
#include <e-util/e-table-field-chooser-item.h>
#include <e-util/e-table-field-chooser.h>
#include <e-util/e-table-group-container.h>
#include <e-util/e-table-group-leaf.h>
#include <e-util/e-table-group.h>
#include <e-util/e-table-header-item.h>
#include <e-util/e-table-header-utils.h>
#include <e-util/e-table-header.h>
#include <e-util/e-table-item.h>
#include <e-util/e-table-model.h>
#include <e-util/e-table-one.h>
#include <e-util/e-table-search.h>
#include <e-util/e-table-selection-model.h>
#include <e-util/e-table-sort-info.h>
#include <e-util/e-table-sorted-variable.h>
#include <e-util/e-table-sorted.h>
#include <e-util/e-table-sorter.h>
#include <e-util/e-table-sorting-utils.h>
#include <e-util/e-table-specification.h>
#include <e-util/e-table-state.h>
#include <e-util/e-table-subset-variable.h>
#include <e-util/e-table-subset.h>
#include <e-util/e-table-utils.h>
#include <e-util/e-table.h>
#include <e-util/e-text-event-processor-emacs-like.h>
#include <e-util/e-text-event-processor-types.h>
#include <e-util/e-text-event-processor.h>
#include <e-util/e-text-model-repos.h>
#include <e-util/e-text-model.h>
#include <e-util/e-text.h>
#include <e-util/e-timezone-dialog.h>
#include <e-util/e-tree-model-generator.h>
#include <e-util/e-tree-model.h>
#include <e-util/e-tree-selection-model.h>
#include <e-util/e-tree-table-adapter.h>
#include <e-util/e-tree-view-frame.h>
#include <e-util/e-tree.h>
#include <e-util/e-unicode.h>
#include <e-util/e-url-entry.h>
#include <e-util/e-util-enums.h>
#include <e-util/e-util-enumtypes.h>
#include <e-util/e-webdav-browser.h>
#ifndef E_UTIL_INCLUDE_WITHOUT_WEBKIT
#include <e-util/e-web-view.h>
#include <e-util/e-web-view-jsc-utils.h>
#include <e-util/e-web-view-preview.h>
#endif
#include <e-util/e-widget-undo.h>
#include <e-util/e-xml-utils.h>
#include <e-util/ea-cell-table.h>
#include <e-util/ea-factory.h>
#include <e-util/gal-view-collection.h>
#include <e-util/gal-view-etable.h>
#include <e-util/gal-view-instance-save-as-dialog.h>
#include <e-util/gal-view-instance.h>
#include <e-util/gal-view.h>

#undef __E_UTIL_H_INSIDE__

#endif /* E_UTIL_H */
